Data Classes
============

.. autoclass:: befordata.BeForRecord
   :members:

.. autoclass:: befordata.BeForEpochs
   :members:


Tools
=====

.. autofunction:: befordata.tools.detect_sessions

.. autofunction:: befordata.tools.butter_filter


csv
===

.. autofunction:: befordata.csv.read_csv_as_befordata

.. autofunction:: befordata.csv.read_csv



